<p align="center">
  <a href="" rel="noopener">
 <img width=200px height=200px src="https://user-images.githubusercontent.com/103124157/164258966-7a049d6c-4012-49ca-8f7d-2bb814c24009.png" alt="WhaBot Logo"></a>
</p>

<h3 align="center">T3SF</h3>

<div align="center">

  [![Status](https://img.shields.io/badge/status-active-success.svg)]() 
  [![PyPI version](https://badge.fury.io/py/T3SF.svg)](https://badge.fury.io/py/T3SF)
  [![Documentation Status](https://readthedocs.org/projects/t3sf/badge/?version=docs)](https://t3sf.readthedocs.io/en/latest/?badge=docs)
  [![License](https://img.shields.io/badge/license-GPL-blue.svg)](/LICENSE)

</div>

<p align="center"> Technical Tabletop Exercises Simulation Framework
    <br> 
</p>

## Table of Contents
- [About](#About)
- [Getting Things Ready](#Starting)
- [TODO](../TODO.md)
- [Contributing](../CONTRIBUTING.md)
- [Authors](#Authors)

## About <a name = "About"></a>
T3SP is a framework that offers a modular structure for the orchestration of events from a master scenario events list (MSEL) together with a set of rules defined for each exercise (optional) and a configuration that allows defining the parameters of the platform used. The main module performs the communication with the specific platform module (Discord, Slack, Telegram, etc.) which allows the events to be presented in the input channels as injects corresponding to each platform.

## Getting Things Ready <a name = "Starting"></a>
WIP

### Prerequisites
WIP

## Usage <a name="Usage"></a>
WIP

## Authors <a name = "Authors"></a>
- [@FedeQuarkB4](https://github.com/FedeQuarkB4) - Idea
- [@lanfranB4](https://github.com/lanfranB4) - Main developer
